@@ -4,12 +4,12 @@
 #' @param phi amplitude, real or complex number
 #' @param m parameter, real or complex number
 #' @param minerror bound on relative error passed to \code{\link{elliptic_E}}
-#' and \code{\link{elliptic_F}}
+#'   and \code{\link{elliptic_F}}
 #'
 #' @return A complex number, the value of the Jacobi zeta function
-#' \ifelse{html}{\out{Z(&phi;,m)}}{\eqn{Z(\phi,m)}{Z(phi,m)}}.
+#'   \ifelse{html}{\out{Z(&phi;,m)}}{\eqn{Z(\phi,m)}{Z(phi,m)}}.
 #' @export
-elliptic_Z <- function(phi, m, minerror = 2*.Machine$double.eps){
+elliptic_Z <- function(phi, m, minerror = 1e-15){
   if(is.infinite(Re(m)) && Im(m) == 0){
     NaN
   }else if(m == 1){
